@@ -1,6 +1,6 @@
 from datetime import datetime, timedelta
+from dateutil import parser as dateutil
 import io
-import json
 import os
 from base64 import b64encode
 import validators
@@ -13,6 +13,7 @@ from typing import (
     Generic,
     Iterable,
     List,
+    Optional,
     TextIO,
     Tuple,
     Type,
@@ -32,13 +33,22 @@ if TYPE_CHECKING:
 class Utterance:
     speaker: str
     utterance: str
+    timestamp: Optional[timedelta] = None
 
     @classmethod
     def from_dict(cls, u: Dict[str, str]) -> "Utterance":
-        return cls(u["speaker"], u["utterance"])
+        return cls(
+            u["speaker"],
+            u["utterance"],
+            timestamp_to_timedelta(u.get("timestamp", None)),
+        )
 
     def __repr__(self) -> str:
-        return f"\n\t{self.speaker}: {self.utterance}"
+        return (
+            f"\n\t{self.timestamp} {self.speaker}: {self.utterance}"
+            if self.timestamp
+            else f"\n\t{self.speaker}: {self.utterance}"
+        )
 
 
 TextContent = TypeVar("TextContent", bound=Union[str, List["Utterance"]])
@@ -51,7 +61,9 @@ CONTENT_TYPES: Dict[str, Tuple[str, str]] = {
     ".srt": ("text/plain", "conversation"),
     ".wav": ("audio/wav", "conversation"),
     ".mp3": ("audio/mpeg", "conversation"),
+    ".mp4": ("audio/mpeg", "conversation"),
     ".html": ("text/plain", "article"),
+    ".pdf": ("text/pdf", "article"),
 }
 
 
@@ -123,7 +135,7 @@ def skillclass(
             )
 
         def __init__(self, *args, **kwargs):
-            cls_init(self, *args, **kwargs)
+            cls_init(self, *args)
             Skill.__init__(
                 self,
                 api_name=api_name,
@@ -134,9 +146,12 @@ def skillclass(
             )
             self._skill_params = [
                 a
-                for a in self.__dict__
-                if not (a in Skill.__dict__ or a == "_skill_params")
+                for a in {**self.__dict__, **kwargs}
+                if a not in Skill.__dataclass_fields__
             ]
+            for param in self._skill_params:
+                if param in kwargs:
+                    self.__setattr__(param, kwargs[param])
 
         cls_init = cls.__init__
         cls.__init__ = __init__
@@ -160,23 +175,27 @@ class Input(Generic[TextContent]):
     `encoding: str`
         The encoding of the input.
     `metadata: dict`
-        Optional metadata to be associated with the input in clustering collections. Not implemented by default.
+        Optional metadata to be associated with the input in clustering collections.
+    `datetime: datetime`
+        Optional datetime to be associated with the input in clustering collections.
     """
 
     def __init__(
         self,
         text: TextContent,
         *,
-        type: str,
+        type: str = None,
         content_type: str = None,
         encoding: str = None,
         metadata: Dict[str, any] = None,
+        datetime: datetime = None,
     ):
         self.text: TextContent = text
         self.type = type
         self.content_type = content_type
         self.encoding = encoding
         self.metadata = metadata
+        self.datetime = datetime
 
     @classmethod
     def wrap(
@@ -215,166 +234,10 @@ class Input(Generic[TextContent]):
             raise ValueError(f"invalid content type {type(text)}")
 
 
-class Document(Input[str]):
-    """
-    Represents any text that doesn't have a structured format
-
-    ## Attributes
-
-    `text: str`
-        The text of the document.
-    """
-
-    def __init__(self, text: str):
-        super().__init__(text, type="article", content_type="text/plain")
-
-
-class Conversation(Input[List[Utterance]]):
-    """
-    Represents conversations.
-
-    ## Attributes
-
-    `text: List[Utterance]`
-        A list of `Utterance` objects, each has `speaker` and `utterance` fields.
-
-    ## Methods
-
-    `parse(text) -> Conversation`
-        A class method. Parse a string with a structued conversation format or a conversation JSON string into a `Conversation` instance.
-    """
-
-    def __init__(self, utterances: List[Utterance] = []):
-        super().__init__(
-            utterances, type="conversation", content_type="application/json"
-        )
-
-    @property
-    def utterances(self):
-        return self.text
-
-    @utterances.setter
-    def utterances(self, value: List[Utterance]):
-        self.text = value
-
-    def __getitem__(self, index: int) -> Utterance:
-        return self.utterances[index]
-
-    @classmethod
-    def parse(cls, text: str) -> "Conversation":
-        """
-        A class method. Parse a string with a structured conversation format or a conversation JSON string into a `Conversation` instance.
-
-        ## Parameters
-
-        `text: str`
-            The text to parse.
-
-        ## Returns
-
-        The `Conversation` instance produced from `text`.
-
-        ## Raises
-
-        `ValueError` if `text` is not in a valid conversation format.
-        """
-        try:  # try to parse as JSON
-            js = json.loads(text)
-            return cls([Utterance(**utterance) for utterance in js])
-        except json.JSONDecodeError:  # if not JSON, assume it's a structured conversation
-            from oneai.parsing import parse_conversation
-
-            return cls(parse_conversation(text))
-
-    def __repr__(self) -> str:
-        return f"oneai.Conversation{repr(self.utterances)}"
-
-
-class File(Input):
-    """
-    Deprecated. Pass file-like objects directly to `Pipeline.run`
-
-    Represents file inputs. Supported file extensions:
-    * .txt (text files)
-    * .wav, .mp3 (transcribe)
-    * .srt (captions)
-    * .jpg (OCR)
-    * .json (One AI conversation JSON format)
-
-    ## Attributes
-
-    `text: str`
-        Encoded file data.
-    `type: str`
-        An input-type hint for the API, either `Conversation` or `Document`.
-    `content_type: str`
-        The content type of the file.
-    `encoding: str`
-        The encoding of the file.
-    """
-
-    def __init__(self, file_path: str, type: Union[str, Type[Input]] = None):
-        """
-        Creates a new `File` input instance
-
-        ## Parameters
-
-        `file_path: str`
-            The path of the file to encode. Supported file extensions: [.txt, .wav, .mp3, .srt, .jpg/.jpeg, .json]
-        `type: str` (optional)
-            The input-type hint for the API, either `Conversation` or `Document`.
-        """
-        warn(
-            "File class is deprecated- pass file-like objects directly to pipelines instead",
-            DeprecationWarning,
-            stacklevel=2,
-        )
-        if type is None or isinstance(type, str):
-            super().__init__(type)
-        elif issubclass(type, Input):
-            super().__init__(type.type)
-        else:
-            raise ValueError(f"Invalid input type {type}")
-
-        utf8, b64 = "utf8", "base64"
-        _, ext = os.path.splitext(file_path)
-        if ext == ".json":
-            self.content_type = "application/json"
-            self.encoding = utf8
-        elif ext == ".txt":
-            self.content_type = "text/plain"
-            self.encoding = utf8
-        elif ext == ".srt":
-            self.text = Conversation.parse(open(file_path).read()).text
-            return
-        elif ext in [".jpg", ".jpeg"]:
-            self.content_type = "image/jpeg"
-            self.encoding = b64
-        elif ext == ".wav":
-            self.content_type = "audio/wav"
-            self.encoding = b64
-        elif ext == ".mp3":
-            self.content_type = "audio/mp3"
-            self.encoding = b64
-        elif ext == ".html":
-            self.content_type = "text/html"
-            self.encoding = utf8
-        else:
-            raise InputError(
-                message=f"unsupported file extension {ext}",
-                details="see supported files in docs",
-            )
-
-        if self.encoding == utf8:
-            self.text = open(file_path, "r").read()
-        else:
-            self.text = b64encode(open(file_path, "rb").read()).decode("utf-8")
-
-
 def timestamp_to_timedelta(timestamp: str) -> timedelta:
     if not timestamp:
         return None
-    dt = datetime.strptime(timestamp, "%H:%M:%S.%f")
+    dt = dateutil.parse(timestamp)
     return timedelta(
         hours=dt.hour, minutes=dt.minute, seconds=dt.second, microseconds=dt.microsecond
     )
@@ -534,10 +397,7 @@ class Output(Input[TextContent], OutputAttrs if TYPE_CHECKING else object):
         The input text from which this `Output` instance was produced.
     `skills: List[Skill]`
         The Skills used to process `text` and produce this `Output` instance.
-    `data: List[List[Label] | Output]`
-        Output data produced by `skills`, in the same order. Each element can be:
-        * A list of labels, marking data points in `text`, e.g entities.
-        * A nested `Output` instance, with a new `text`, e.g summary.
+    See `OutputAttrs` for the attributes generated by different Skills.
     """
 
     def __init__(
@@ -552,27 +412,9 @@ class Output(Input[TextContent], OutputAttrs if TYPE_CHECKING else object):
             content_type="text/plain" if isinstance(text, str) else "application/json",
         )
 
-        self.skills = (
-            skills  # not a dict since Skills are currently mutable & thus unhashable
-        )
-        self.data = data
-
-    def __getitem__(self, name: str) -> Union[Labels, "Output"]:
-        return self.__getattr__(name)
-
-    def __getattr__(self, name: str) -> Union[Labels, "Output"]:
-        #####TEMP#HACK########
-        if name in ["business_entities", "pricing"] and hasattr(self, "labs"):
-            return getattr(self.__getattr__("labs"), name)
-        ######################
-        for i, skill in enumerate(self.skills):
-            if (
-                (skill.api_name and skill.api_name == name)
-                or (skill.output_attr and name in skill.output_attr)
-                or (type(skill).__name__ == name)
-            ):
-                return self.data[i]
-        raise AttributeError(f"{name} not found in {self}")
+        self.skills = skills
+        for skill, value in zip(skills, data):
+            setattr(self, skill.output_attr or skill.api_name, value)
 
     def __dir__(self) -> Iterable[str]:
         return super().__dir__() + [
@@ -581,6 +423,7 @@ class Output(Input[TextContent], OutputAttrs if TYPE_CHECKING else object):
 
     def __repr__(self) -> str:
         result = f"oneai.Output(text={repr(self.text)}"
-        for i, skill in enumerate(self.skills):
-            result += f", {skill.output_attr or skill.api_name}={repr(self.data[i])}"
+        for skill in self.skills:
+            attr = skill.output_attr or skill.api_name
+            result += f", {attr}={repr(getattr(self, attr))}"
         return result + ")"
