@@ -2,11 +2,21 @@ import logging
 
 PREFIX = "\33[34m●\33[36m▲\33[35m▮\33[0m"
 
+notebook = False
+try:
+    if get_ipython().__class__.__name__ == "ZMQInteractiveShell":
+        notebook = True
+except NameError:
+    pass
+
 
 class Formatter(logging.Formatter):
     def format(self, record):
         if record.levelno == logging.DEBUG:
-            self._style._fmt = f"\033[K{PREFIX} %(message)s\033[F"
+            if notebook:
+                self._style._fmt = f"{PREFIX} %(message)s\r"
+            else:
+                self._style._fmt = f"\033[K{PREFIX} %(message)s\033[F"
         if record.levelno == logging.DEBUG + 1:
             self._style._fmt = ""
         elif record.levelno == logging.WARNING:
