@@ -28,7 +28,7 @@ class TranscriptionEnhancer(Skill):
 
     ## Example
 
-    >>> conversation = oneai.Conversation([...])
+    >>> conversation = [oneai.Utterance(...), ...]
     >>> pipeline = oneai.Pipeline(steps=[
     ...     oneai.skills.TranscriptionEnhancer()
     ... ])
@@ -68,7 +68,7 @@ class Proofread(Skill):
 
     ## Example
 
-    >>> conversation = oneai.Conversation([...])
+    >>> conversation = [oneai.Utterance(...), ...]
     >>> pipeline = oneai.Pipeline(steps=[
     ...     oneai.skills.Proofread()
     ... ])
@@ -465,6 +465,7 @@ class Pricing(Skill):
 
 
 @skillclass(api_name="names", label_type="name")
+@dataclass
 class Names(Skill):
     """
     Detects and classifies names in the input
@@ -484,6 +485,9 @@ class Names(Skill):
     [oneai.Label(type=entity, name=PERSON, span=[0, 3], value=Jim), oneai.Label(type=entity, name=ORG, span=[21, 31], value=Acme Corp.)]
     """
 
+    enrichment: bool = False
+    amount: Literal["more", "less", "normal"] = None
+
 
 @skillclass(api_name="numbers", label_type="number")
 class Numbers(Skill):
@@ -550,6 +554,7 @@ class SplitByTopic(Skill):
     """
 
     std_ratio: float = 0
+    amount: Literal["more", "less", "normal"] = None
     use_discourse_parser: bool = False
 
 
